@@ -17,7 +17,6 @@ import qualified Data.ByteString.Lazy as BSL
 import qualified URI.ByteString as URI
 import Network.HTTP.Conduit
 import Network.OAuth.OAuth2
-import Network.OAuth.OAuth2.TokenRequest as OA
 import Control.Monad (liftM, mplus, mzero)
 import Data.Maybe
 import Data.Aeson
@@ -37,7 +36,7 @@ loginGithubUser githubKey params = do
   let destination = pDestination params `orIfNull` (base' ++ "/")
   key <- newSession $ sessionDataGithubStateUrl state destination
   cfg <- getConfig
-  addCookie (MaxAge $ sessionTimeout cfg) (mkCookie "sid" (show key))
+  addCookie (MaxAge $ sessionTimeout cfg) (mkSessionCookie key)
   let usingOrg = isJust $ org $ githubAuth cfg
   let scopes = "user:email" ++ if usingOrg then ",read:org" else ""
   let url = appendQueryParams [("state", BS.pack state), ("scope", BS.pack scopes)] $ authorizationUrl githubKey
