@@ -28,7 +28,7 @@ module Network.Gitit.Types (
                            , AuthenticationLevel(..)
                            , Config(..)
                            , Page(..)
-                           , SessionKey
+                           , SessionKey(..)
                            -- we do not export SessionData constructors, in case we need to extend  SessionData with other data in the future
                            , SessionData
                            , SessionGithubData
@@ -169,6 +169,8 @@ data Config = Config {
   -- be given the prompt and must give
   -- one of the answers to register.
   accessQuestion       :: Maybe (String, [String]),
+  -- | Disable Registration?
+  disableRegistration  :: Bool,
   -- | Use ReCAPTCHA for user registration.
   useRecaptcha         :: Bool,
   recaptchaPublicKey   :: String,
@@ -202,8 +204,6 @@ data Config = Config {
   feedDays             :: Integer,
   -- | Number of minutes to cache feeds before refreshing
   feedRefreshTime      :: Integer,
-  -- | Allow PDF export?
-  pdfExport            :: Bool,
   -- | Directory to search for pandoc customizations
   pandocUserData       :: Maybe FilePath,
   -- | Filter HTML through xss-sanitize
@@ -227,7 +227,8 @@ data Page = Page {
   , pageMeta        :: [(String, String)]
 } deriving (Read, Show)
 
-type SessionKey = Integer
+newtype SessionKey = SessionKey Integer
+  deriving (Read, Show, Eq, Ord)
 
 data SessionData = SessionData {
   sessionUser :: Maybe String,
@@ -245,7 +246,7 @@ sessionData user = SessionData (Just user) Nothing
 sessionDataGithubStateUrl :: String -> String -> SessionData
 sessionDataGithubStateUrl githubState destination = SessionData Nothing (Just $ SessionGithubData githubState destination)
 
-data Sessions a = Sessions {unsession::M.Map SessionKey a}
+data Sessions a = Sessions {unsession :: M.Map SessionKey a}
   deriving (Read,Show,Eq)
 
 -- Password salt hashedPassword
@@ -370,13 +371,10 @@ data Params = Params { pUsername     :: String
                      , pRedirect     :: Maybe Bool
                      }  deriving Show
 
-instance FromReqURI [String] where
-  fromReqURI s = case fromReqURI s of
-                      Just (s' :: String) ->
-                                   case reads s' of
-                                        ((xs,""):_) -> xs
-                                        _           -> Nothing
-                      Nothing             -> Nothing
+instance FromReqURI SessionKey where
+ fromReqURI s = case fromReqURI s of
+                       Just i -> Just $ SessionKey i
+                       Nothing -> Nothing
 
 instance FromData Params where
      fromData = do
@@ -467,7 +465,7 @@ instance FromData Command where
        return $ case map fst pairs `intersect` commandList of
                  []          -> Command Nothing
                  (c:_)       -> Command $ Just c
-               where commandList = ["update", "cancel", "export"]
+               where commandList = ["update", "cancel"]
 
 -- | State for a single wiki.
 data WikiState = WikiState {
